load2 which per
default caches loaded objects and returns the cached version
in subsequent calls.
makeFileCache(use.cache = TRUE)logical(1)]
Enable the cache?
Default is TRUE.function()] with argument slot
(name of the slot to cache the object in, default is default).
All other arguments are passed down to load2.